#
# spec file for package ghc-generic-deriving
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name generic-deriving
Name:           ghc-%{pkg_name}
Version:        1.10.5
Release:        7.11
Summary:        Generic programming library for generalised deriving
License:        BSD-3-Clause
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides functionality for generalising the deriving mechanism in
Haskell to arbitrary classes. It was first described in the paper:

* /A generic deriving mechanism for Haskell/. Jose Pedro Magalhaes, Atze
Dijkstra, Johan Jeuring, and Andres Loeh. Haskell'10.

The current implementation integrates with the new GHC Generics. See
<http://www.haskell.org/haskellwiki/GHC.Generics> for more information.
Template Haskell code is provided for supporting GHC before version 7.2.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md examples

%changelog
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.10.5 revision 0 with cabal2obs.
* Sun Jun 19 2016 mimi.vx@gmail.com
- update to 1.10.5
  * Apply an optimization to generated to(1)/from(1) instances that factors
    out common occurrences of M1
  * Export internal typeclass names
  * Fix Haddock issues with GHC 7.8
* Mon May 23 2016 mimi.vx@gmail.com
- update to 1.10.4.1
  * Fix Haddock parsing issue on GHC 8.0
  * Backported MonadPlus and MonadZip instances for U1, and made the Functor,
  Foldable, Traversable, Alternative, and Monad instances for U1 lazier to
  correspond with base-4.9
  * Backported Enum, Bounded, Ix, Functor, Applicative, Monad, MonadFix, MonadPlus,
  MonadZip, Foldable, Traversable, and Data instances (introduced in base-4.9)
  for datatypes in the Generics.Deriving.Base module
  * Added Generics.Deriving.Semigroup
  * Added GMonoid instance for Data.Monoid.Alt
  * Fixed a bug in the GEnum instances for unsigned Integral types
  * Added Safe/Trustworthy pragmas
  * Made instances polykinded where possible
  * On GHC 8.0 and up, Generics.Deriving.TH uses the new type literal-based machinery
  * Rewrote the Template Haskell code to be robust. Among other things, this fixes
  a bug with deriving Generic1 instances on GHC 7.8, and makes it easier to
  derive Generic1 instances for datatypes that utilize GHC 8.0's
  - XTypeInType extension.
  * Added deriveAll0 and makeRep0 for symmetry with deriveAll1 and makeRep1
  * AddedmakeRep0FromType and makeRep1FromType to make it easier to pass in the type
  instance
  * Added functions with the suffix -WithKindSigs to allow generating type synonyms
  with explicit kind signatures in the presence of kind-polymorphic type
  variables. This is necessary for some datatypes that use -XTypeInType to have
  derived Generic(1) instances, but is not turned on by default since the TH
  kind inference is not perfect and would cause otherwise valid code to be
  rejected. Use only if you know what you are doing.
  * Fixed bug where a datatype with a single, nullary constructor would generate
  incorrect Generic instances
  * More sensible GEnum instances for fixed-size integral types
  * Added GCopoint, GEnum, GEq, GFoldable, GFunctor, GMonoid, GShow, and GTraversable
  instances for datatypes introduced in GHC 8.0
  * Backported Generic(1) instances added in GHC 8.0. Specifically, Generic instances
  for Complex (base-4.4 and later) ExitCode, and Version; and Generic1 instances
  for Complex (base-4.4 and later) and Proxy (base-4.7 and later). Added GEnum,
  GEq, GFoldable, GFunctor, GIx, GShow, and GTraversable instances for these
  datatypes where appropriate.
* Mon May 16 2016 mimi.vx@gmail.com
- package ghc-generic-deriving updated by st2obs
* Wed May 11 2016 mimi.vx@gmail.com
- package ghc-generic-deriving updated by st2obs
* Sat Feb 13 2016 mimi.vx@gmail.com
- ghc-generic-deriving generated by st2obs scritpt
